@@ -292,12 +292,26 @@ class ChessGame(game.ChessGame):
 
     def save(self):
         """Save this game"""
-        if len(self.getMoves()) < 2:
-            return
         pgnGame = chess.pgn.PGNGame()
         self.toPGN(pgnGame)
-        self.application.history.save(pgnGame, self.fileName)
+        if self.inHistory:
+            # Don't bother if haven't made any significant moves
+            if len(self.getMoves()) < 2:
+                return
+            self.application.history.save(pgnGame, self.fileName)
+        else:
+            try:
+                f = file(self.fileName, 'w')
+                lines = pgnGame.getLines()
+                for line in lines:
+                    f.write(line + '\n')
+                f.write('\n')
+                f.close()
+            except IOError, e:
+                return e.args[1]
+
         self.setNeedsSaving(False)
+        self.application.logger.addLine('Saved game %s to %s' % (repr(self.name), self.fileName))
         
 class UI(ui.UIFeedback):
     """
@@ -378,7 +392,7 @@ class UI(ui.UIFeedback):
         try:
             p = chess.pgn.PGN(path, 1)
         except chess.pgn.Error, e:
-            return e.description
+            return e.message
         except IOError, e:
             return e.strerror
         
@@ -428,7 +442,7 @@ class Application:
         
         self.history = history.GameHistory()
         
-        self.logger = self.ui.controller.addLogWindow('Application Log', '', '')
+        self.logger = self.ui.controller.addLogWindow(_('Application Log'), '', '')
 
     def addAIProfile(self, profile):
         """Add a new AI profile into glChess.
@@ -455,8 +469,10 @@ class Application:
     def watchAIPlayer(self, p):
         """
         """
-        self.ioHandlers[p.fileno()] = p
-        self.ui.controller.watchFileDescriptor(p.fileno())
+        fd = p.fileno()
+        if fd is not None:
+            self.ioHandlers[fd] = p
+            self.ui.controller.watchFileDescriptor(fd)
 
     def unwatchAIPlayer(self, p):
         """
@@ -584,15 +600,20 @@ class Application:
 
         # Get the last player to resign if the file specifies it
         result = pgnGame.getTag(chess.pgn.TAG_RESULT, None)
+        loser = None
         if result == chess.pgn.RESULT_DRAW:
-            if newGame.result == game.RESULT_IN_PROGRESS:
-                newGame.getCurrentPlayer().resign()
-            elif newGame.result != game.RESULT_DRAW:
-                print 'PGN file specifies draw, glChess expects a win'
+            newGame.claimDraw()
+            if newGame.result != game.RESULT_DRAW:
+                newGame.endGame(game.RESULT_DRAW, game.RULE_AGREEMENT)
+        elif result == chess.pgn.RESULT_INCOMPLETE:
+            if newGame.result != game.RESULT_IN_PROGRESS:
+                print "WARNING: PGN file specifies game in progress, glChess does't..."            
         elif result == chess.pgn.RESULT_WHITE_WIN:
-            print 'FIXME: Handle white win in PGN'
+            loser = newGame.getBlack()
         elif result == chess.pgn.RESULT_BLACK_WIN:
-            print 'FIXME: Handle black win in PGN'
+            loser = newGame.getWhite()
+        if newGame.result == game.RESULT_IN_PROGRESS and loser is not None:
+            loser.resign()
 
         duration = 0
         value = pgnGame.getTag(chess.pgn.TAG_TIME_CONTROL)
@@ -724,11 +745,11 @@ class Application:
 
     def __autoload(self):
         """Restore games from the autosave file"""
-        (pgnGame, fileName) = self.history.getUnfinishedGame()
+        (pgnGame, fileName, inHistory) = self.history.getUnfinishedGame()
         if pgnGame is not None:
             g = self.addPGNGame(pgnGame, fileName)
             if g is not None:
-                g.inHistory = True
+                g.inHistory = inHistory
 
 if __name__ == '__main__':
     app = Application()
