@@ -50,9 +50,9 @@ prompt for usage and a list of options.
 """
 
 
-__revision__ = '$Rev: 7653 $'
-__date__ = '$Date: 2008-05-14 06:45:25 -0500 (Wed, 14 May 2008) $'
-__author__ = '$Author: rancell $'
+__revision__ = '$Rev$'
+__date__ = '$Date$'
+__author__ = '$Author$'
 
 
 import sys
